@@ -4,22 +4,17 @@ import numpy as np
 from mlagents.trainers.policy.tf_policy import TFPolicy
 from .model import BCModel
 from mlagents.trainers.demo_loader import demo_to_buffer
-from mlagents.trainers.exception import UnityTrainerException
+from mlagents.trainers.settings import BehavioralCloningSettings
 
 
 class BCModule:
     def __init__(
         self,
         policy: TFPolicy,
+        settings: BehavioralCloningSettings,
         policy_learning_rate: float,
         default_batch_size: int,
         default_num_epoch: int,
-        strength: float,
-        demo_path: str,
-        steps: int,
-        batch_size: int = None,
-        num_epoch: int = None,
-        samples_per_update: int = 0,
     ):
         """
         A BC trainer that can be used inline with RL.
@@ -36,14 +31,16 @@ class BCModule:
         :param samples_per_update: Maximum number of samples to train on during each BC update.
         """
         self.policy = policy
-        self.current_lr = policy_learning_rate * strength
-        self.model = BCModel(policy, self.current_lr, steps)
+        self.current_lr = policy_learning_rate * settings.strength
+        self.model = BCModel(policy, self.current_lr, settings.steps)
         _, self.demonstration_buffer = demo_to_buffer(
-            demo_path, policy.sequence_length, policy.brain
+            settings.demo_path, policy.sequence_length, policy.brain
         )
 
-        self.batch_size = batch_size if batch_size else default_batch_size
-        self.num_epoch = num_epoch if num_epoch else default_num_epoch
+        self.batch_size = (
+            settings.batch_size if settings.batch_size else default_batch_size
+        )
+        self.num_epoch = settings.num_epoch if settings.num_epoch else default_num_epoch
         self.n_sequences = max(
             min(self.batch_size, self.demonstration_buffer.num_experiences)
             // policy.sequence_length,
@@ -52,29 +49,13 @@ class BCModule:
 
         self.has_updated = False
         self.use_recurrent = self.policy.use_recurrent
-        self.samples_per_update = samples_per_update
+        self.samples_per_update = settings.samples_per_update
         self.out_dict = {
             "loss": self.model.loss,
             "update": self.model.update_batch,
             "learning_rate": self.model.annealed_learning_rate,
         }
 
-    @staticmethod
-    def check_config(config_dict: Dict[str, Any]) -> None:
-        """
-        Check the behavioral_cloning config for the required keys.
-        :param config_dict: Pretraining section of trainer_config
-        """
-        param_keys = ["strength", "demo_path", "steps"]
-        for k in param_keys:
-            if k not in config_dict:
-                raise UnityTrainerException(
-                    "The required pre-training hyper-parameter {0} was not defined. Please check your \
-                    trainer YAML file.".format(
-                        k
-                    )
-                )
-
     def update(self) -> Dict[str, Any]:
         """
         Updates model using buffer.
